@@ -18,3 +18,6 @@
 #undef HAVE_GETTEXT
 #undef HAVE_CATGETS
 #undef LOCALEDIR
+
+/* where to look for unicode data */
+#undef UNICODEDATA
